@@ -1,4 +1,5 @@
 import enum
+import copy
 
 from collections import OrderedDict
 from typing import List
@@ -48,10 +49,16 @@ class Generator:
     @staticmethod
     def _validate_cloud(cloud=None):
         if cloud:
+            # TODO - make it better!
+            cloud_copy = {
+                "cloud": cloud["type"],
+                "region": cloud["region"],
+                "account": cloud["account"],
+            }
             try:
-                cloud_type = cloud.get("type")
+                cloud_type = cloud_copy.pop("cloud")
                 cloud_dataclass = cloud_map[cloud_type]
-                return cloud_dataclass(**cloud)
+                return cloud_dataclass(**cloud_copy)
             except Exception as e:
                 raise ValueError(f"Cloud validation error {str(e)}")
         else:
